@@ -1,7 +1,6 @@
-/* $Id: wmwork.c,v 1.67 2005/12/02 07:36:59 godisch Exp $
- * vim: set noet ts=4:
+/* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2005 Martin A. Godisch <martin@godisch.de>
+ * Copyright (c) 2002-2013 Martin A. Godisch <martin@godisch.de>
  */
 
 #include <assert.h>
@@ -99,6 +98,11 @@ int main(int argc, char *argv[])
 
 	assert(sizeof(char) == 1);
 
+	if (getenv("HOME") == NULL || *getenv("HOME") == 0) {
+		fprintf(stderr, "%s: unknown $HOME directory, please check your environment\n", PACKAGE_NAME);
+		return -1;
+	}
+
 	umask(077);
 	do_opts(argc, argv, &show_days, &xdisplay, &geometry, &force);
 
@@ -345,7 +349,7 @@ void do_opts(int argc, char *argv[], int *show_days, char **xdisplay, char **geo
 		case 'v':
 #endif /* SOLARIS */
 			printf("%s %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-			printf("copyright (c) 2002-2005 Martin A. Godisch <martin@godisch.de>\n");
+			printf("copyright (c) 2002-2013 Martin A. Godisch <martin@godisch.de>\n");
 			exit(0);
 #ifdef SOLARIS
 			} else if (!strcmp(argv[i], "--display"))
